from django.db import models


class Namespace(models.Model):
    prefix = models.CharField(max_length=255, unique=True)
    uri = models.CharField(max_length=255)

    def __str__(self):
        return f"{self.prefix}: {self.uri}"
